<?php

namespace Assetdocs\Student\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Student\Interfaces\StudentRepositoryInterface;
use Assetdocs\Student\Repositories\Presenter\StudentItemTransformer;

/**
 * Pubic API controller class.
 */
class StudentApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Student\Interfaces\StudentRepositoryInterface $student
     *
     * @return type
     */
    public function __construct(StudentRepositoryInterface $student)
    {
        $this->middleware('api');

        $this->repository = $student;
        parent::__construct();
    }

    /**
     * Show student's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $students = $this->repository
            ->pushCriteria(new \Assetdocs\Student\Repositories\Criteria\StudentPublicCriteria())
            ->setPresenter('\\Assetdocs\\Student\\Repositories\\Presenter\\StudentListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $students['code'] = 2000;
        return response()->json($students)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show student.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $student = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($student)) {
            $student         = $this->itemPresenter($module, new StudentItemTransformer);
            $student['code'] = 2001;
            return response()->json($student)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
